@@ -455,6 +455,20 @@ namespace xt
         }
 #endif
     }
+
+#if defined(__GNUC__) && !defined(__clang__)
+    namespace workaround
+    {
+        // Fixes "undefined symbol" issues
+        inline void long_long_allocator()
+        {
+            std::allocator<long long> a;
+            std::allocator<unsigned long long> b;
+            std::allocator<double> c;
+            std::allocator<std::complex<double>> d;
+        }
+    }
+#endif
 }
 
 #endif
